@@ -161,7 +161,6 @@ vardannual <- function(Y, H, PSU, w_final, ID_level1,
    ids <- nams <- cros_se <- num1 <- totalY <- totalZ <- NULL
    estim_1 <- estim_2 <- avar <- N <- estim <- NULL
    var_est2 <- se <- rse <- cv <- CI_lower <- CI_upper <- NULL
-   absolute_margin_of_error <- relative_margin_of_error <- NULL
    Nr_sar <- cols <- Nrs <- percoun <- totalY_male <- NULL
    totalZ_male <- totalY_female <- totalZ_female <- NULL  
 
@@ -384,14 +383,14 @@ vardannual <- function(Y, H, PSU, w_final, ID_level1,
    annual_results[, se := sqrt(var_est2)]
    annual_results[, var_est2 := NULL]
 
-   if (method == "cros")  { annual_results[, rse := se / estim]
-                            annual_results[, cv := rse * 100] }
+   annual_results[, rse := se / estim]
+   annual_results[, cv := rse * 100] 
 
    tsad <- qnorm(0.5 * (1 + confidence))
-   if (method == "cros") {
-          annual_results[, absolute_margin_of_error := tsad * se]
-          annual_results[, relative_margin_of_error := tsad * cv]
-   }
+   absolute_margin_of_error <- relative_margin_of_error <- NULL
+   annual_results[, absolute_margin_of_error := tsad * se]
+   annual_results[, relative_margin_of_error := tsad * cv]
+ 
    annual_results[, CI_lower := estim - tsad * se]
    annual_results[, CI_upper := estim + tsad * se]
 
